import { Button } from '@/components/ui/button';
import { Card, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import FrontLayout from '@/layouts/frontend-layout';
import { Link } from '@inertiajs/react';
import { Calendar, ChevronRight } from 'lucide-react';

const blogPosts = [
    {
        id: 1,
        title: 'Top 10 Places to Visit in Sri Lanka',
        excerpt: 'From pristine beaches to misty mountains, discover the must-visit destinations in Sri Lanka that will take your breath away.',
        author: 'Rajith Perera',
        date: '2025-04-02',
        image: 'https://images.unsplash.com/photo-1589308078059-be1415eab4c3',
        category: 'Travel Guide',
    },
    {
        id: 2,
        title: 'Sri Lankan Cuisine: A Flavorful Journey',
        excerpt:
            'Explore the rich and diverse flavors of Sri Lankan cuisine, from spicy curries to sweet desserts that will tantalize your taste buds.',
        author: 'Amaya Fernando',
        date: '2025-03-15',
        image: 'https://images.unsplash.com/photo-1606471191009-63994c53433b',
        category: 'Food & Culture',
    },
    {
        id: 3,
        title: 'Wildlife Safari: Spotting Leopards in Yala National Park',
        excerpt: 'Tips and tricks for maximizing your chances of spotting the elusive Sri Lankan leopard during your wildlife safari adventure.',
        author: 'Dinesh Silva',
        date: '2025-02-28',
        image: 'https://images.unsplash.com/photo-1549366021-9f761d450615',
        category: 'Wildlife',
    },
    {
        id: 4,
        title: 'Sustainable Tourism in Sri Lanka',
        excerpt: "How travelers can contribute to preserving Sri Lanka's natural beauty and cultural heritage through responsible tourism practices.",
        author: 'Priya Wickramasinghe',
        date: '2025-02-10',
        image: 'https://images.unsplash.com/photo-1588668214407-6ea9a6d8c272',
        category: 'Eco-Tourism',
    },
    {
        id: 5,
        title: "Ancient Ruins: Exploring Sri Lanka's Cultural Triangle",
        excerpt:
            "Journey through time as we explore the ancient cities of Anuradhapura, Polonnaruwa, and Sigiriya - the heart of Sri Lanka's rich history.",
        author: 'Rajith Perera',
        date: '2025-01-20',
        image: 'https://images.unsplash.com/photo-1593693397690-362cb9666fc2',
        category: 'History',
    },
    {
        id: 6,
        title: 'The Perfect 7-Day Sri Lanka Itinerary',
        excerpt: "Make the most of your week in Sri Lanka with this carefully crafted itinerary covering the island's most remarkable attractions.",
        author: 'Amaya Fernando',
        date: '2025-01-05',
        image: 'https://images.unsplash.com/photo-1593693397690-362cb9666fc2',
        category: 'Travel Guide',
    },
];

const formatDate = (dateString: string | number | Date) => {
    const date = new Date(dateString);
    return new Intl.DateTimeFormat('en-US', {
        year: 'numeric',
        month: 'long',
        day: 'numeric',
    }).format(date);
};

const BlogList = () => {
    return (
        <FrontLayout>
            <div className="min-h-screen">
                <div className="pt-24">
                    <div className="container mx-auto mt-12 mb-8 px-4">
                        <div className="container grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
                            {blogPosts.map((post) => (
                                <Card
                                    key={post.id}
                                    className="hover-float flex h-full flex-col overflow-hidden border-0 shadow-md transition-all duration-300 hover:shadow-xl"
                                >
                                    <div className="h-48 overflow-hidden">
                                        <img
                                            src={post.image}
                                            alt={post.title}
                                            className="h-full w-full object-cover transition-transform duration-500 hover:scale-110"
                                        />
                                    </div>
                                    <div className="bg-primary absolute top-4 right-4 rounded-full px-3 py-1 text-xs font-bold text-white">
                                        {post.category}
                                    </div>
                                    <CardHeader>
                                        <div className="mb-2 flex items-center text-sm text-gray-500">
                                            <Calendar size={14} className="mr-1" />
                                            <span>{formatDate(post.date)}</span>
                                        </div>
                                        <CardTitle className="font-display text-xl">{post.title}</CardTitle>
                                        <CardDescription className="line-clamp-3">{post.excerpt}</CardDescription>
                                    </CardHeader>
                                    <CardFooter className="mt-auto pt-0 ">
                                        <Link href={`/blog/${post.id}`} className='text-primary flex items-center p-0'>
                                            Read More <ChevronRight size={16} className="ml-1 text-primary" />
                                        </Link>
                                    </CardFooter>
                                </Card>
                            ))}
                        </div>
                    </div>
                </div>
            </div>
            <div className="min-h-screen"></div>
        </FrontLayout>
    );
};

export default BlogList;
